@@ -1,7 +1,8 @@
+import warnings
 from rdkit import Chem
 import numpy as np
 from rdkit.Chem import AllChem, MACCSkeys, DataStructs
-from typing import Iterable, List, Union
+from typing import Iterable, List, Union, Optional
 import pandas as pd
 from stse.dataframes import z_norm as stse_z_norm
 
@@ -51,7 +52,8 @@ def smiles_2_inchi_keys(smiles:Iterable[str]) -> List[str]:  # *
     return mols_2_inchi_keys(smiles_2_mols(smiles))
 
 def mols_2_ecfp(mols:Iterable[Chem.rdchem.Mol], radius:int=2, return_numpy:bool=False,
-                n_bits:int=1024) -> List[Union[np.array, DataStructs.cDataStructs.UIntSparseIntVect]]:
+                n_bits:Optional[int]=1024,
+                use_chirality:bool=True) -> List[Union[np.array, DataStructs.cDataStructs.UIntSparseIntVect]]:
     """Converts from rdkit mol objects to morgan fingerprints (full ECFP6).
 
     :param mols: Collection of mols
@@ -61,17 +63,23 @@ def mols_2_ecfp(mols:Iterable[Chem.rdchem.Mol], radius:int=2, return_numpy:bool=
     :return: Collection of ECFP vectors
     :rtype: list[rdkit BitVect]
     """
-    if return_numpy:
-        fingerprints = [AllChem.GetMorganFingerprintAsBitVect(m, radius, nBits=n_bits) for m in mols]
-        
-        X = []
-        for fp in fingerprints:
-            arr = np.array([])
-            DataStructs.ConvertToNumpyArray(fp, arr)
-            X.append(arr)
-        return X
+    if not n_bits:
+        if return_numpy:
+            warnings.warn('Cannot return numpy array if n_bits is None. Returning \
+                DataStructs.cDataStructs.UIntSparseIntVect instead.', UserWarning)
+        return [AllChem.GetMorganFingerprint(m, radius, useChirality=use_chirality) for m in mols]
     else:
-        return [AllChem.GetMorganFingerprint(m, radius) for m in mols]
+        fingerprints = [AllChem.GetMorganFingerprintAsBitVect(m, radius, useChirality=use_chirality, nBits=n_bits) \
+            for m in mols]
+        
+        if return_numpy:
+            X = []
+            for fp in fingerprints:
+                arr = np.array([])
+                DataStructs.ConvertToNumpyArray(fp, arr)
+                X.append(arr)
+            return X
+        return fingerprints
 
 def mols_2_maccs(mols:Iterable[Chem.rdchem.Mol]) -> List[DataStructs.cDataStructs.ExplicitBitVect]:
     """Converts from mol objects to MACCS keys.
@@ -84,7 +92,7 @@ def mols_2_maccs(mols:Iterable[Chem.rdchem.Mol]) -> List[DataStructs.cDataStruct
     return [MACCSkeys.GenMACCSKeys(m) for m in mols]
 
 def mols_2_ecfp_plus_descriptors(mols:Iterable[Chem.rdchem.Mol], other_df:pd.DataFrame, z_norm:bool=True,
-                          ecfp_radius:int=2) -> np.array:
-    ecfp_X = mols_2_ecfp(mols, radius=ecfp_radius, return_numpy=True)
+                          ecfp_radius:int=2, ecfp_n_bits:int=1024) -> np.array:
+    ecfp_X = mols_2_ecfp(mols, radius=ecfp_radius, n_bits=ecfp_n_bits, return_numpy=True)
     other_X = stse_z_norm(other_df).to_numpy() if z_norm else other_df.to_numpy()
     return np.concatenate((ecfp_X, other_X), axis=1)
