@@ -47,20 +47,17 @@ class TestMolConversion(unittest.TestCase):
 
     def test_mols_2_ecfp(self):
         ecfp = mol_conversion.mols_2_ecfp(self.sdf_mols, return_numpy=True)
-        self.assertEqual(
-            len(ecfp[0]),
-            1024
-        )
-        self.assertIsInstance(
-            ecfp[0],
-            np.ndarray
-        )
+        self.assertIsInstance(ecfp[0], np.ndarray)
+        self.assertEqual(len(ecfp[0]), 1024)
         
         print_objs = mol_conversion.mols_2_ecfp(self.sdf_mols, return_numpy=False)
-        self.assertIsInstance(
-            print_objs[0],
-            DataStructs.cDataStructs.UIntSparseIntVect
-        )
+        self.assertIsInstance(print_objs[0], DataStructs.cDataStructs.ExplicitBitVect)
+        
+        print_objs = mol_conversion.mols_2_ecfp(self.sdf_mols, n_bits=None, return_numpy=False)
+        self.assertIsInstance(print_objs[0], DataStructs.cDataStructs.UIntSparseIntVect)
+        
+        with self.assertWarns(UserWarning):
+            print_objs = mol_conversion.mols_2_ecfp(self.sdf_mols, n_bits=None, return_numpy=True)
         
     def test_mols_2_maccs(self):
         maccss = mol_conversion.mols_2_maccs(self.sdf_mols)
